% vestnik2.cls
%
% This is LaTeX2e class support for submissions authors manuscripts to journal 
% 'Ecological Bulletin of Research Centers of the Black Sea Economic Cooperation'
%
% Latest version of this file can be found on the web page of journal 
% 'Ecological Bulletin of Research Centers of the Black Sea Economic 
%    Cooperation' at http://vestnik.kubsu.ru/vestnik2
% 
% This package may be distributed and/or modified under the conditions of the 
% LaTeX Project Public License, either version 1.3 of this license or any later 
% version. The latest version of this license is in
%    http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX version 
% 2005/12/01 or later.
%
% This package may consists of the following source files:
% LaTeX style class file:
%    vestnik2.cls
% Documentation files:
%    vestnik2-guide.tex, vestnik2-guide.pdf
% Pictures for documentation:
%    vestnik2-guide1.eps, vestnik2-guide1.pdf
%    vestnik2-guide2a.eps, vestnik2-guide2a.png
%    vestnik2-guide2b.eps, vestnik2-guide2b.png
% Template files:
%    vestnik2-template.tex Russian template (Unicode UTF-8 encoding)
%    vestnik2-template1251.tex Russian template (Windows Cyrillic CP1251 encoding)
% Read Me:
%    readme.txt Russian readme (Unicode UTF-8 encoding)
%    readme1251.txt Russian readme (Windows Cyrillic CP1251 encoding)
%
% Style class Vestnik2 uses the packages:
%    amsmath, amssymb, amsthm, babel, caption, cite, cmap, geometry, graphicx, 
%    extsizes, epstopdf, fancyhdr, fontenc, indentfirst, ifthen, mathtext, 
%    microtype, multicol, rotating, subcaption, tabularx, textcomp, xstring,
%    xparse.
%
% 2.1  2016/09/18 * The \authorinfo command. It can be used instead of the 
%                   \inforus command, which is left for compatibility with 
%                   previous version. 
%                 * One condition is that the commands \authorinfo and \inforus 
%                   cannot be mixed in one article.
%                 * Fixed ability to use environment proof for English-language 
%                   articles
%                 * The command \d to specify a roman style of the differential
%                   symbol after the integral symbol
% 2.0f 2015/02/19 Fix \bm command
% 2.0e 2014/10/06 New justification parameter Q{} for taburarx environment with 
%                 left aligned text and width option
% 2.0d 2014/09/26 Minor bug fixed
% 2.0c 2014/08/25 Fixed compatible with MikTeX 2.9
% 2.0  2014/08/01 Version 2.0 is not compatible with previous versions:
%                 * encoding of files is UTF-8 (Unicode) by default. To compile 
%                   files in CP1251 (Windows Cyrillic) encoding need to specify 
%                   the class option [cp1251]
%                 * preparation of articles in English made possible
%                   (the class option [english])
%                 * Renamed \title -> \titlerus, \refrus -> \briefrus,
%                   udk -> udc
%                 * description of authors in Russian and English is fully 
%                   changed (\authorrus, \inforus, \addressrus, \authoreng, 
%                   \addresseng, \email)
%                 * Support for extended abstracts and references for 
%                   international abstract and citation databases
%                   (\annotationeng, \annotationrus, thereferences)
%                 * command \grant is excluded. To specify the grants you can 
%                   use command \thanks
%                 * rarely used environments 'theorem', 'newthm', 'lemma', 
%                   'definition', 'remark', 'example' excluded. Instead a new 
%                   environment 'prop' was defined
% 1.1  2008/01/12 Support for keywords (keywordsrus, keywordseng)
% 1.0  2006/02/01 Initial release
% 
% Report questions/bugs to <vestnik@kubsu.ru>
%
% Copyright 2006, 2008, 2014 
% (c) 'Ecological Bulletin of Research Centers of the Black Sea Economic 
%      Cooperation'
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
\ProvidesClass{vestnik2}[09/18/2016 version 2.1]

\message
 {^^J=====================================================================
  ^^J vestnik2 version 2.1 (09/18/2016) LaTeX2e paper class for journal 
  ^^J 'Ecological Bulletin of Research Centers of the Black Sea Economic 
  ^^J  Cooperation'
  ^^J=====================================================================^^J^^J}
\makeatletter
\newlinechar=`\^^J
\def\class@warning#1{%
    \ClassWarningNoLine{vestnik2}{#1}
}
\def\class@error#1{%
    \ClassError{vestnik2}{#1}{See LaTeX Documentation for more help}
}
\RequirePackage{ifthen}
\RequirePackage{xparse}

\newboolean{@preprint}
\setboolean{@preprint}{true}
\newboolean{@merge}
\setboolean{@merge}{false}
\newboolean{@leng}
\setboolean{@leng}{false}
\newboolean{@comments}
\setboolean{@comments}{false}
\newboolean{@utf8enc}
\setboolean{@utf8enc}{true}

\DeclareOption{press}{\setboolean{@preprint}{false}}
\DeclareOption{merge}{\setboolean{@merge}{true}}
\DeclareOption{cp1251}{\setboolean{@utf8enc}{false}}
\DeclareOption{english}{\setboolean{@leng}{true}}
\DeclareOption{comments}{\setboolean{@comments}{true}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\def\@classoptionslist{a4paper,twoside}

\ProcessOptions

\ifthenelse{\boolean{@merge}}{%
    \ifthenelse{\boolean{@preprint}}{%
        \class@error{Invalid combination of class options}}{}}{}

%%%%%%% Connect for necessary packages
\LoadClass[11pt]{extarticle}
\RequirePackage{cmap}
\RequirePackage[warn]{mathtext}
\RequirePackage[T1,T2A]{fontenc}
\ifthenelse{\boolean{@utf8enc}}{%
    \RequirePackage[utf8x]{inputenc}
    \RequirePackage{ucs}}{%
    \RequirePackage[cp1251]{inputenc}
    \RequirePackage{cm-super}
}
\RequirePackage[english,russian]{babel}

\ifthenelse{\boolean{@comments}}{%
    \RequirePackage[svgnames,rgb]{xcolor}
    \RequirePackage[color=yellow,author={Editor},subject={Note},icon=Help]{pdfcomment}
    \defineliststyle{vestnik2}{%
        \textcolor{red} {\pc@lopt@author}:\ \pc@lopt@comment}
    \setliststyle{vestnik2}
    \newcommand{\pdfmc}[2]{\pdfmarkupcomment{#1}{#2}}
    \newcommand{\pdfc}[1]{\pdfcomment{#1}}
}{}

\RequirePackage{amsmath,amssymb,amsthm}
\RequirePackage{multicol,cite,indentfirst,fancyhdr}
\renewcommand\citemid{,~}
\RequirePackage[center,small,labelsep=period]{caption}
\RequirePackage{subcaption}
\renewcommand\thesubfigure{\asbuk{subfigure}}
\DeclareCaptionLabelFormat{opening}{#2)}
\captionsetup[subfigure]{labelformat=opening}

\RequirePackage{graphicx,rotating,epstopdf,tabularx}
\RequirePackage{textcomp}
\RequirePackage[letterspace=200]{microtype}

\ifthenelse{\boolean{@preprint}}{}{%
    \ifthenelse{\boolean{@merge}}{%
        \RequirePackage{newfile}}{}
}
\ifthenelse{\boolean{@preprint}}{%
    \RequirePackage[14pt]{extsizes}
    \RequirePackage[mag=1000,a4paper,%
                    inner=2.5cm,outer=2.5cm,top=2.5cm,bottom=2.5cm,%
                    ignoreheadfoot]{geometry}
    \renewcommand{\baselinestretch}{1.4}}{%
    \RequirePackage[mag=1000,a4paper,%
                    inner=2.5cm,outer=2.5cm,top=2cm,bottom=2cm,%
                    includeheadfoot]{geometry}
    \renewcommand{\baselinestretch}{0.9}
    }
\binoppenalty=10000 \relpenalty=10000
\clubpenalty=10000 \widowpenalty=10000
\ifthenelse{\boolean{@preprint}}{%
    \tolerance=1000}{}
\ifthenelse{\boolean{@leng}}{}{%
    \frenchspacing}
\defineshorthand[russian]{"/}{\mbox{-}\bbl@allowhyphens}

%%%%%%% Strings definitions
\def\@enspace{\medspace}
\def\sel@V@r{\selectlanguage{russian}}
\def\sel@V@e{\selectlanguage{english}}
\def\s@V@issn{ISSN 1729-5459}
\def\s@V@name{%
     \IeC{\CYREREV}\IeC{\CYRK}\IeC{\CYRO}\IeC{\CYRL}\IeC{\CYRO}\IeC{\CYRG}%
     \IeC{\CYRI}\IeC{\CYRCH}\IeC{\CYRE}\IeC{\CYRS}\IeC{\CYRK}\IeC{\CYRI}%
     \IeC{\CYRISHRT}\@enspace\IeC{\CYRV}\IeC{\CYRE}\IeC{\CYRS}\IeC{\CYRT}%
     \IeC{\CYRN}\IeC{\CYRI}\IeC {\CYRK}\@enspace\IeC{\CYRN}\IeC{\CYRA}%
     \IeC{\CYRU}\IeC{\CYRCH}\IeC{\CYRN}\IeC{\CYRERY}\IeC{\CYRH}\@enspace%
     \IeC{\CYRC}\IeC{\CYRE}\IeC{\CYRN}\IeC{\CYRT}\IeC{\CYRR}\IeC{\CYRO}%
     \IeC{\CYRV}\@enspace\IeC{\CYRCH}\IeC{\CYREREV}\IeC{\CYRS}%
}
\def\s@V@fullname{%
    {\IeC{\CYREREV}\IeC{\cyrk}\IeC{\cyro}\IeC{\cyrl}\IeC{\cyro}\IeC{\cyrg}%
    \IeC{\cyri}\IeC{\cyrch}\IeC{\cyre}\IeC{\cyrs}\IeC{\cyrk}\IeC{\cyri}%
    \IeC{\cyrishrt}\@enspace\IeC{\cyrv}\IeC{\cyre}\IeC{\cyrs}\IeC{\cyrt}%
    \IeC{\cyrn}\IeC{\cyri}\IeC{\cyrk}\@enspace\IeC{\cyrn}\IeC{\cyra}%
    \IeC{\cyru}\IeC{\cyrch}\IeC{\cyrn}\IeC{\cyrery}\IeC{\cyrh}\@enspace%
    \IeC{\cyrc}\IeC{\cyre}\IeC{\cyrn}\IeC{\cyrt}\IeC{\cyrr}\IeC{\cyro}%
    \IeC{\cyrv}\@enspace\IeC{\CYRCH}\IeC{\cyre}\IeC{\cyrr}\IeC{\cyrn}%
    \IeC{\cyro}\IeC{\cyrm}\IeC{\cyro}\IeC{\cyrr}\IeC{\cyrs}\IeC{\cyrk}%
    \IeC{\cyro}\IeC{\cyrg}\IeC{\cyro}\@enspace\IeC{\cyrerev}\IeC{\cyrk}%
    \IeC{\cyro}\IeC{\cyrn}\IeC{\cyro}\IeC{\cyrm}\IeC{\cyri}\IeC{\cyrch}%
    \IeC{\cyre}\IeC{\cyrs}\IeC{\cyrk}\IeC{\cyro}\IeC{\cyrg}\IeC{\cyro}%
    \@enspace\IeC{\cyrs}\IeC{\cyro}\IeC{\cyrt}\IeC{\cyrr}\IeC{\cyru}%
    \IeC{\cyrd}\IeC{\cyrn}\IeC{\cyri}\IeC{\cyrch}\IeC{\cyre}\IeC{\cyrs}%
    \IeC{\cyrt}\IeC{\cyrv}\IeC{\cyra}}%
}
\def\s@V@udc{\IeC{\CYRU}\IeC{\CYRD}\IeC{\CYRK}%
}
\def\s@V@annotationeng{\IeC{\CYRR}\IeC{\cyra}\IeC{\cyrs}\IeC{\cyrsh}%
	\IeC{\cyri}\IeC{\cyrr}\IeC{\cyre}\IeC{\cyrn}\IeC{\cyrn}\IeC{\cyra}%
	\IeC{\cyrya}\@enspace\IeC{\cyra}\IeC{\cyrn}\IeC{\cyrn}\IeC{\cyro}%
	\IeC{\cyrt}\IeC{\cyra}\IeC{\cyrc}\IeC{\cyri}\IeC {\cyrya}\@enspace%
	\IeC{\cyrn}\IeC{\cyra}\@enspace\IeC{\cyra}\IeC{\cyrn}\IeC{\cyrg}%
	\IeC{\cyrl}\IeC{\cyri}\IeC{\cyrishrt}\IeC{\cyrs}\IeC{\cyrk}\IeC{\cyro}%
	\IeC{\cyrm}\@enspace\IeC{\cyrya}\IeC{\cyrz}\IeC{\cyrery}\IeC{\cyrk}%
	\IeC{\cyre}\@enspace(150--250\@enspace\IeC{\cyrs}\IeC{\cyrl}\IeC{\cyro}%
	\IeC{\cyrv}):\par%
}
\def\s@V@annotationengpress{Abstract.%
}
\def\s@V@keywordseng{{\IeC{\CYRK}\IeC{\cyrl}\IeC{\cyryu}\IeC{\cyrch}%
	\IeC{\cyre}\IeC{\cyrv}\IeC{\cyrery}\IeC{\cyre}\@enspace\IeC{\cyrs}%
	\IeC{\cyrl}\IeC{\cyro}\IeC{\cyrv}\IeC{\cyra}\@enspace\IeC{\cyrn}%
	\IeC{\cyra}\@enspace\IeC{\cyra}\IeC{\cyrn}\IeC{\cyrg}\IeC{\cyrl}%
	\IeC{\cyri}\IeC{\cyrishrt}\IeC{\cyrs}\IeC{\cyrk}\IeC{\cyro}\IeC{\cyrm}%
	\@enspace\IeC{\cyrya}\IeC{\cyrz}\IeC{\cyrery}\IeC{\cyrk}\IeC{\cyre}%
	\@enspace(\IeC{\cyrn}\IeC{\cyre}\@enspace\IeC{\cyrm}\IeC{\cyre}%
	\IeC{\cyrn}\IeC{\cyre}\IeC{\cyre}\@enspace7\@enspace\IeC{\cyrk}%
	\IeC{\cyrl}\IeC{\cyryu}\IeC{\cyrch}\IeC{\cyre}\IeC{\cyrv}\IeC{\cyrery}%
	\IeC {\cyrh}\@enspace\IeC{\cyrs}\IeC{\cyrl}\IeC{\cyro}\IeC{\cyrv })}:\par%
}
\def\s@V@keywordsengpress{Keywords:%
}
\def\s@V@keywordsrus{\textit{%
    \IeC{\CYRK}\IeC{\cyrl}\IeC{\cyryu}\IeC{\cyrch}\IeC{\cyre}\IeC{\cyrv}%
    \IeC{\cyrery}\IeC{\cyre}\@enspace\IeC{\cyrs}\IeC{\cyrl}\IeC{\cyro}%
    \IeC{\cyrv}\IeC{\cyra}}\@enspace(\IeC{\cyrn}\IeC{\cyre}\@enspace%
    \IeC{\cyrm}\IeC{\cyre}\IeC{\cyrn}\IeC{\cyre}\IeC{\cyre}\@enspace7%
    \@enspace\IeC{\cyrk}\IeC{\cyrl}\IeC{\cyryu}\IeC{\cyrch}\IeC{\cyre}%
    \IeC{\cyrv}\IeC{\cyrery}\IeC{\cyrh}\@enspace\IeC{\cyrs}\IeC{\cyrl}%
    \IeC{\cyro}\IeC{\cyrv}):\par%
}
\def\s@V@datesend{\IeC{\CYRD}\IeC{\cyra}\IeC{\cyrt}\IeC{\cyra}\@enspace%
    \IeC{\cyro}\IeC {\cyrt}\IeC{\cyrs}\IeC{\cyrery}\IeC{\cyrl}\IeC{\cyrk}%
    \IeC{\cyri}\@enspace\IeC{\cyrs}\IeC{\cyrt}\IeC{\cyra}\IeC{\cyrt}%
    \IeC{\cyrsftsn}\IeC{\cyri}%
}
\def\s@V@daterecived{\IeC{\CYRS}\IeC{\cyrt}\IeC{\cyra}\IeC{\cyrt}%
    \IeC{\cyrsftsn}\IeC{\cyrya}\@enspace\IeC{\cyrp}\IeC{\cyro}\IeC{\cyrs}%
    \IeC{\cyrt}\IeC{\cyru}\IeC{\cyrp}\IeC{\cyri}\IeC{\cyrl}\IeC{\cyra}%
}
\def\s@V@appendix{\IeC{\CYRP}\IeC{\cyrr}\IeC{\cyri}\IeC{\cyrl}\IeC{\cyro}%
    \IeC{\cyrzh}\IeC{\cyre}\IeC{\cyrn}\IeC{\cyri}\IeC{\cyre}%
}
\def\s@V@authchapt{\IeC{\CYRI}\IeC{\cyrn}\IeC{\cyrf}\IeC{\cyro}\IeC{\cyrr}%
    \IeC{\cyrm}\IeC{\cyra}\IeC{\cyrc}\IeC{\cyri}\IeC{\cyrya}\@enspace%
    \IeC{\cyro}\IeC{\cyrb}\@enspace\IeC{\cyra}\IeC{\cyrv}\IeC{\cyrt}%
    \IeC{\cyro}\IeC{\cyrr}\IeC{\cyra}\IeC{\cyrh}%
}
\def\s@V@shortref{\IeC{\CYRK}\IeC{\cyrr}\IeC{\cyra}\IeC{\cyrt}\IeC{\cyrk}%
	\IeC{\cyri}\IeC{\cyrishrt}\@enspace\IeC{\cyrr}\IeC{\cyre}\IeC{\cyrf}%
	\IeC{\cyre}\IeC{\cyrr }\IeC{\cyra}\IeC{\cyrt}\@enspace(\IeC{\cyrn}%
	\IeC{\cyre}\@enspace\IeC{\cyrb}\IeC{\cyro}\IeC{\cyrl}\IeC{\cyre}%
	\IeC{\cyre}\@enspace850\@enspace\IeC{\cyrs}\IeC{\cyri}\IeC{\cyrm}%
	\IeC{\cyrv}\IeC{\cyro}\IeC{\cyrl}\IeC{\cyro}\IeC{\cyrv}):\par%
}
\def\s@V@annotationtranslate{\IeC{\CYRP}\IeC{\cyre}\IeC{\cyrr}\IeC{\cyre}%
	\IeC{\cyrv}\IeC{\cyro}\IeC{\cyrd}\@enspace\IeC{\cyrr}\IeC{\cyra}%
	\IeC{\cyrs}\IeC{\cyrsh}\IeC{\cyri}\IeC{\cyrr}\IeC{\cyre}\IeC{\cyrn}%
	\IeC{\cyrn}\IeC{\cyro}\IeC{\cyrishrt}\@enspace\IeC{\cyra}\IeC{\cyrn}%
	\IeC{\cyrn}\IeC{\cyro}\IeC{\cyrt}\IeC{\cyra}\IeC{\cyrc}\IeC{\cyri}%
	\IeC{\cyri}\@enspace\IeC{\cyrn}\IeC{\cyra}\@enspace\IeC{\cyrr}%
	\IeC{\cyru}\IeC{\cyrs}\IeC{\cyrs}\IeC{\cyrk}\IeC{\cyri}\IeC{\cyrishrt}%
	\@enspace\IeC{\cyrya}\IeC{\cyrz}\IeC{\cyrery}\IeC{\cyrk}:\par%
}
\def\s@V@theorem{\IeC{\CYRT}\IeC{\cyre}\IeC{\cyro}\IeC{\cyrr}\IeC{\cyre}%
    \IeC{\cyrm}\IeC{\cyra}%
}
\def\s@V@proofrus{\IeC{\CYRD}\IeC{\cyro}\IeC{\cyrk}\IeC{\cyra}\IeC{\cyrz}%
    \IeC{\cyra}\IeC{\cyrt}\IeC{\cyre}\IeC{\cyrl}\IeC{\cyrsftsn}\IeC{\cyrs}%
    \IeC{\cyrt}\IeC{\cyrv}\IeC{\cyro}%
}
\def\s@V@proofeng{Proof%
}
\def\s@V@descriptionbib{\IeC{\CYRB}\IeC{\cyri}\IeC{\cyrb}\IeC{\cyrl}\IeC{\cyri}%
    \IeC {\cyro}\IeC{\cyrg}\IeC{\cyrr}.%
}
\def\s@V@descriptionbibname{\IeC{\cyrn}\IeC{\cyra}\IeC{\cyrz}\IeC{\cyrv}.%
}
\def\s@V@descriptionfig{\IeC{\CYRI}\IeC{\cyrl}.%
}
\def\s@V@descriptiontbl{\IeC{\CYRT}\IeC{\cyra}\IeC{\cyrb}\IeC{\cyrl}.%
}
\def\s@V@descriptionpgs{\IeC{\cyrs}\IeC{\cyrt}\IeC{\cyrr}.%
}
\def\s@V@lit{\IeC{\CYRL}\IeC{\cyri}\IeC{\cyrt}\IeC{\cyre}\IeC{\cyrr}\IeC{\cyra}%
    \IeC{\cyrt}\IeC{\cyru}\IeC{\cyrr}\IeC{\cyra}%
}
\def\s@V@noteslist{\IeC{\CYRS}\IeC{\cyrp}\IeC{\cyri}\IeC{\cyrs}\IeC{\cyro}%
    \IeC{\cyrk}\@enspace\IeC{\cyrz}\IeC{\cyra}\IeC{\cyrm}\IeC{\cyre}\IeC{\cyrch}%
    \IeC{\cyra}\IeC{\cyrn}\IeC{\cyri}\IeC{\cyrishrt}
}

%%%%%%% Users commands
\newcommand{\udc}{}
\newcommand{\theudc}{}
\renewcommand{\udc}[1]{%
    \renewcommand{\theudc}{{\s@V@udc\enspace#1}}
}
\newcommand{\doi}{}
\newcommand{\thedoi}{}
\renewcommand{\doi}[1]{%
    \renewcommand{\thedoi}{{doi:\enspace#1}}
}
\newcommand{\rubric}{}
\newcommand{\therubric}{}
\renewcommand{\rubric}[1]{%
    \renewcommand{\therubric}{{\lsstyle #1}}
}
\newcommand{\titlerus}{}
\newcommand{\thetitlerus}{}
\newcommand{\thetitleshort}{}
\newcommand{\thetitleheader}{}
\renewcommand{\titlerus}[2][]{%
    \renewcommand{\thetitleheader}{#2}
    \renewcommand{\thetitlerus}{#2}
    \ifthenelse{\equal{#1}{}}{%
        \renewcommand{\thetitleshort}{\thetitlerus}}{%
        \renewcommand{\thetitleshort}{#1}}
}
\newcommand{\titleeng}{}
\newcommand{\thetitleeng}{}
\newcommand{\thetitleengshort}{}
\renewcommand{\titleeng}[2][]{%
    \ifthenelse{\equal{#1}{}}  
        {\renewcommand{\thetitleeng}{{#2}}}
        {\renewcommand{\thetitleeng}{{#2}}
        \renewcommand{\thetitleengshort}{{#1}}}
}
\newcommand{\authorrus}{}
\newcommand{\theauthorrus}{}
\newcommand{\theauthorrus@other}{}

\renewcommand{\authorrus}[2][]{%
    \ifthenelse{\equal{\theauthorrus}{}}
        {\g@addto@macro\theauthorrus{#2}
        \g@addto@macro\theauthorrus@other{#2$^\text{#1}$}}
        {\g@addto@macro\theauthorrus{, #2}
        \g@addto@macro\theauthorrus@other{, #2$^\text{#1}$}}
}
\newcommand{\theauthorrus@hided}{%
    \let\thefootnote\relax\theauthorrus
}
\newcommand{\authorinfo@other}{}
\newcommand{\theauthorinfo@other}{}
\renewcommand{\authorinfo@other}[1]{%
    \renewcommand{\theauthorinfo@other}{{#1}}
}
\newcommand\inforus[1]{%
    \ifthenelse{\boolean{@preprint}}
        {\g@addto@macro\theauthorinfo@other{\par#1}}
        {\let\thefootnote\relax%
            \protect\footnotetext{\protect\sel@V@r#1}}%
}
\newcommand\authorinfo[1]{%
    \ifthenelse{\boolean{@preprint}}
        {\g@addto@macro\theauthorinfo@other{\par#1}}
        {\let\thefootnote\relax%
            \protect\footnotetext{\protect\sel@V@r#1}}%
}
\newcommand{\addressrus}{}
\newcommand{\theaddressrus}{}
\newcommand{\theaddressrus@other}{}
\renewcommand{\addressrus}[2][]{%
    \ifthenelse{\equal{\theaddressrus}{}}
        {\g@addto@macro\theaddressrus{#2}
        \g@addto@macro\theaddressrus@other{$^\text{#1}$\thinspace#2}}
        {\g@addto@macro\theaddressrus{\par #2}
        \g@addto@macro\theaddressrus@other{\par$^\text{#1}$\thinspace#2}}
}
\newcommand{\authoreng}{}
\newcommand{\theauthoreng}{}
\newcommand{\theauthoreng@other}{}
\renewcommand{\authoreng}[2][]{%
    \ifthenelse{\equal{\theauthoreng}{}}
        {\g@addto@macro\theauthoreng{#2$^\text{#1}$}
        \g@addto@macro\theauthoreng@other{#2}}
        {\g@addto@macro\theauthoreng{, #2$^\text{#1}$}
        \g@addto@macro\theauthoreng@other{, #2}}
}
\newcommand{\addresseng}{}
\newcommand{\theaddresseng}{}
\renewcommand{\addresseng}[2][]{%
    \ifthenelse{\equal{\theaddresseng}{}}
        {\g@addto@macro\theaddresseng{$^\text{#1}$\thinspace#2}}
        {\g@addto@macro\theaddresseng{\par$^\text{#1}$\thinspace#2}}
}
\newcommand{\email}{}
\newcommand{\theemail}{}
\renewcommand{\email}[1]{%
    \renewcommand{\theemail}{{e-mail:\enspace#1}}
}
\newcommand{\authorsshort}{}
\newcommand{\theauthorsshort}{}
\renewcommand{\authorsshort}[1]{%
    \renewcommand{\theauthorsshort}{{#1}}
}
\newcommand{\briefrus}{}
\newcommand{\thebriefrus}{}
\renewcommand{\briefrus}[1]{%
    \renewcommand{\thebriefrus}{{#1}}
}
\newcommand{\annotationeng}{}
\newcommand{\theannotationeng}{}
\renewcommand{\annotationeng}[1]{%
    \renewcommand{\theannotationeng}{{#1}}
}
\newcommand{\annotationrus}{}
\newcommand{\theannotationrus}{}
\renewcommand{\annotationrus}[1]{%
    \renewcommand{\theannotationrus}{{#1}}
}
\newcommand{\keywordsrus}{}
\newcommand{\thekeywordsrus}{}
\renewcommand{\keywordsrus}[1]{%
    \renewcommand{\thekeywordsrus}{{#1}}
}
\newcommand{\keywordseng}{}
\newcommand{\thekeywordseng}{}
\renewcommand{\keywordseng}[1]{%
    \renewcommand{\thekeywordseng}{{#1}}
}
\newcommand{\thethanks}{}
\renewcommand{\thanks}[1]{%
    \renewcommand{\thethanks}{#1}
}
\newcommand{\thedate}{}
\renewcommand{\date}[1]{%
    \renewcommand{\thedate}{{#1}}
}
\newcommand{\YEAR}{}
\newcommand{\theYEAR}{}
\renewcommand{\YEAR}[1]{%
    \renewcommand{\theYEAR}{{#1}}
}
\newcounter{counter@pages}
\newcounter{counter@lastpage}
\newcounter{counter@firstpage}

%%%%%%% Titul Page
\def\make@titulline{%
    \vbox{}\vspace{-18mm}
    \ifthenelse{\boolean{@merge}}{\vspace{14pt}}{%
        \vbox{\noindent\scriptsize\hfil\s@V@issn.\footnotesize\@enspace\sel@V@r\s@V@name}
    }
    \vspace{0.5ex}\par
    \hrule\par
    \vspace{3ex}
}
\def\make@rubric{%
    \ifthenelse{\equal{\therubric}{}}
        {{\vspace{17.5pt}}}
        {{\centering\sel@V@r\Large\textsc{\textbf{\therubric}}\par\vspace{1mm}}}
}
\newcommand{\Capitalize}[1]{%
  \edef\@tempa{\expandafter\@gobble\string#1}%
  \edef\@tempb{\expandafter\@car\@tempa\@nil}%
  \edef\@tempa{\expandafter\@cdr\@tempa\@nil}%
  \uppercase\expandafter{\expandafter\def\expandafter\@tempb\expandafter{\@tempb}}%
  \@namedef{\@tempb\@tempa}{\expandafter\MakeUppercase\expandafter{#1}}
}
\def\make@maintitle{%
    \ifthenelse{\boolean{@preprint}}
        {\ifthenelse{\boolean{@leng}}
            {\linespread{1.05}\sel@V@e\large\bf\thetitleeng\vspace{1ex}}
            {\linespread{1.05}\sel@V@r\large\bf\thetitlerus\vspace{1ex}}}
        {\ifthenelse{\boolean{@leng}}
            {\linespread{1.05}\sel@V@e\large\bf\MakeUppercase\thetitleeng}
            {\linespread{1.05}\sel@V@r\large\bf\MakeUppercase\thetitlerus}
        \ifthenelse{\equal{\thethanks}{}}{}
            {\let\thefootnote\relax\footnotetext{\linespread{.87}%
                \protect\sel@V@r\thethanks}%
                \setcounter{footnote}{0}}}
}
\def\make@mainauthor{%
    \normalsize\normalfont
    \ifthenelse{\boolean{@leng}}
        {\vspace{1ex}
        \parbox{.9\textwidth}
            {\centering\sel@V@e\textbf{\theauthoreng}\par
            \vspace{2pt}
            \small\theaddresseng\par
            \theemail}}
        {\centering\sel@V@r\textbf{\theauthorrus@hided}}
}
\newenvironment{v@parbox}[1]{%
    \list{}{\leftmargin#1 \rightmargin\leftmargin}%
        \item\relax\par}
    {\endlist}
\def\make@annotations{%
    \begin{center}
        \small
        \ifthenelse{\boolean{@leng}}
            {\vspace{1ex}}
            {\parbox{.9\textwidth}{%
            	\linespread{1}
	            \sel@V@e\centering
	            \MakeUppercase{\thetitleeng}\par}}
        \par\vspace{-1ex}
        \ifthenelse{\boolean{@leng}}{}
            {\vspace{3ex}
            \parbox{.9\textwidth}{
                {\sel@V@e\small
                \centering\theauthoreng\par
                \vspace{4pt}
                \footnotesize
                \theaddresseng\par
                \centering\theemail\par}}}
        \begin{v@parbox}{4ex}
            \normalfont\small
            \parindent=2ex
            \hspace{2ex}
            \textit{\s@V@annotationengpress}\@enspace{\sel@V@e\theannotationeng}\par
            \vspace{2pt}
            \textit{\s@V@keywordsengpress}\@enspace{\sel@V@e\thekeywordseng}
            \vspace{2ex}
        \end{v@parbox}
    \end{center}
}
\renewcommand{\maketitle}{%
    \setcounter{counter@firstpage}
        {\value{page}}
    \ifthenelse{\boolean{@preprint}}{%
        \pagestyle{plain}
        \raggedbottom}{%
        \thispagestyle{empty}
        \make@titulline
        \make@rubric%
        }
    \noindent
    {\sel@V@r\theudc\hfill
    \ifthenelse{\boolean{@preprint}}
        {}{\small\textsf{\thedoi}}}
    \begin{center}
        \make@maintitle
        \par\vspace{1ex}
        \make@mainauthor
    \end{center}
    \vspace{-1ex}
    \ifthenelse{\boolean{@preprint}}{%
        \vspace{1ex}}
        {\make@annotations
        \normalfont\normalsize
        \begin{multicols}{2}}
    \ifthenelse{\boolean{@leng}}{}{%
        \mathchardef\mathcomma\mathcode`\,
        \mathcode`\,="8000
        \bgroup
            \uccode`\~`\,%
            \uppercase{%
        \egroup
        \def~}{\futurelet\@let@token\v@comma}
        \newcommand\ordcommalist{0123456789}
        \def\v@comma{%
            \let\@tempb\@empty
            \expandafter\@tfor\expandafter\@tempa\expandafter:\expandafter=%
            \ordcommalist\do{%
                \expandafter\ifx\@tempa\@let@token
                \let\@tempb\mathord \@break@tfor
                \fi
            }%
            \@tempb\mathcomma
        }
    }
    \ifthenelse{\boolean{@leng}}
        {\sel@V@e}
        {\sel@V@r}
}

%%%%%%% Final information
\newcommand\make@writeref{%
        \newoutputstream{ref}
        \openoutputfile{\jobname.ref}{ref}
        \addtostream{ref}{\theudc\protect\par}
        \ifthenelse{\boolean{@leng}}
            {\addtostream{ref}{\protect\textbf{\theauthorrus}}}
            {\addtostream{ref}{\protect\textbf{\theauthorrus}}}
        \ifthenelse{\boolean{@leng}}
            {\addtostream{ref}{\thetitlerus\protect\par}}
            {\addtostream{ref}{\thetitlerus\protect\par}}
        \addtostream{ref}{\thebriefrus\protect\par}
        \addtostream{ref}{\s@V@keywordsrus\@enspace\thekeywordsrus\protect\par}
        \ifnum\c@figure=0
            \else\addtostream{ref}{\s@V@descriptionfig\@enspace\@arabic\c@figure.}\fi
        \ifnum\c@table=0
            \else\addtostream{ref}{\s@V@descriptiontbl\@enspace\@arabic\c@table.}\fi
        \addtostream{ref}{\s@V@descriptionbib\@enspace%
            \@arabic\c@enumiv\@enspace%
            \s@V@descriptionbibname\protect\par}
        \closeoutputstream{ref}
        \relax
}
\def\make@endline{%
    \parindent 0ex
    \vspace{1ex}
    \hrule height .5pt
    \vspace{2ex}
    \ifthenelse{\boolean{@preprint}}
        {\sel@V@r\s@V@datesend\@enspace\thedate}
        {\footnotesize 
        \sel@V@r\s@V@daterecived\@enspace\thedate\par
        \vspace{2mm}
        \hangindent=3.4ex
        \hangafter=1
        \raggedright
        \textcopyright\@enspace\theauthorrus@hided%
        \ifthenelse{\boolean{@merge}}{%
            \ifthenelse{\equal{\theYEAR}{}}
                {\class@error{\noexpand\YEAR command is undefined.^^J% 
                     Don't run with [merge] option}}
                {, \theYEAR}}{}
        \setcounter{counter@lastpage}{\value{page}}
    }
}
\def\make@preprintauxonerus{%
    \noindent
    \sel@V@r\theudc
    \begin{center}
        \textbf{\sel@V@r\thetitlerus}\par
        \vspace{1ex}
        \sel@V@r\theauthorrus@other\par
        \vspace{1ex}
        \small
        \sel@V@r\theaddressrus@other\par
        \theemail\par
    \end{center}
    \parskip=0ex
    \normalsize
    \textit{\s@V@shortref}\@enspace{\sel@V@r\thebriefrus}\par
    \bigskip
    \noindent
    \textit{\s@V@keywordsrus}\@enspace{\sel@V@r\thekeywordsrus}\par
    \medskip
    \newcounter{@V@tmp}%
    \setcounter{@V@tmp}{\value{page}}%
    \addtocounter{@V@tmp}{-1}%
    \noindent
    \ifnum\c@figure=0\else{\s@V@descriptionfig}\@enspace\@arabic\c@figure.\@enspace\fi
    \ifnum\c@table=0\else{\s@V@descriptiontbl}\@enspace\@arabic\c@table.\@enspace\fi
    \s@V@descriptionbib\@enspace%
    \@arabic\c@enumiv\@enspace%
    \s@V@descriptionbibname\enspace%
    \textemdash\enspace
    \arabic{@V@tmp}\@enspace\s@V@descriptionpgs\par
}
\def\make@preprintauxoneeng{%
    \sel@V@e
    \begin{center}
        \textbf{\thetitleeng}\par\nopagebreak
        \vspace{1ex}
        \theauthoreng\par\nopagebreak
        \vspace{1ex}
        \small
        \theaddresseng\par\nopagebreak
        \theemail\par
    \end{center}
    \textit{\sel@V@r\s@V@annotationeng}\@enspace{\sel@V@e\theannotationeng}\par
    \bigskip
    \noindent
    \textit{\sel@V@r\s@V@keywordseng}\@enspace{\sel@V@e\thekeywordseng}\par
    \vspace{1em}\noindent
    \sel@V@r
    \textit{\s@V@annotationtranslate}\@enspace{\sel@V@r\theannotationrus}
}
\def\make@preprintauxone{%
    \pagestyle{fancy}
    \lhead[]{}
    \chead[]{}\cfoot[\thepage]{\thepage}
    \rhead[\sel@V@r\sc\small\s@V@appendix\enspace1]
        {\sel@V@r\sc\small\s@V@appendix\enspace1}
    \renewcommand{\headrulewidth}{0pt}
    \make@preprintauxonerus
    \vspace{1ex}
    \make@preprintauxoneeng
}
\def\make@preprintauxtwo{%
    \pagestyle{fancy}
    \lhead[]{}
    \chead[]{}\cfoot[\thepage]{\thepage}
    \rhead[\sel@V@r\sc\small\s@V@appendix\enspace2]
        {\sel@V@r\sc\small\s@V@appendix\enspace2}
    \renewcommand{\headrulewidth}{0pt}
    \begingroup
        \sel@V@r
        \section*{\s@V@authchapt}
        \theauthorinfo@other
    \endgroup
    \ifthenelse{\boolean{@comments}}{%
        \newpage
        \pagestyle{fancy}
        \lhead[]{}
        \chead[]{}\cfoot[\thepage]{\thepage}
        \rhead[\sel@V@r\sc\small\s@V@appendix\enspace3]
            {\sel@V@r\sc\small\s@V@appendix\enspace3}
        \renewcommand{\headrulewidth}{0pt}
    	\listofpdfcomments[heading={\s@V@noteslist}]}{}
}
\def\make@annotationcheck{%
    \setcounter{counter@pages}{\value{counter@lastpage}}
    \addtocounter{counter@pages}{-\value{counter@firstpage}}
    \addtocounter{counter@pages}{1}\par
    \bigskip
    {\it\s@V@shortref}\@enspace{\sel@V@r\thebriefrus}\par
    \smallskip
    \textit{\s@V@keywordsrus}\@enspace{\sel@V@r\thekeywordsrus}\par
    \smallskip
    \ifnum\c@figure=0\else{\s@V@descriptionfig}\@enspace\@arabic\c@figure.\fi
    \@enspace
    \ifnum\c@table=0\else{\s@V@descriptiontbl}\@enspace\@arabic\c@table.\fi
    \@enspace
    \s@V@descriptionbib\@enspace%
    \@arabic\c@enumiv\@enspace%
    \s@V@descriptionbibname\enspace%
    \textemdash\enspace%
    \arabic{counter@pages}\@enspace%
    \s@V@descriptionpgs\par
    \bigskip
    \textit{\s@V@annotationtranslate}\@enspace{\sel@V@r\theannotationrus}
    \ifthenelse{\boolean{@comments}}{%
    	\listofpdfcomments[heading={\s@V@noteslist}]}{}
}
\newcommand{\makeendtitle}{%
    \ifthenelse{\boolean{@preprint}}{}
        {\end{multicols}}
    \vspace{2ex}
    \noindent
    \parbox{\textwidth}{\make@endline}
    \ifthenelse{\boolean{@preprint}}{%
        \newpage
        \make@preprintauxone
        \newpage
        \make@preprintauxtwo
        }{%
        \ifthenelse{\boolean{@merge}}
            {\make@writeref}
            {\make@annotationcheck}}
}

%%%%%%% The definition for the bibliography
\renewcommand\@biblabel[1]{#1.\hfill}
\renewenvironment{thebibliography}[1]{%
    \sel@V@r
    \ifthenelse{\equal{\thethanks}{}}{}{%
        \ifthenelse{\boolean{@preprint}}{%
            \bigskip\thethanks}{}%
        }%
    \section*{\textbf{\s@V@lit}}%
        \list{\@biblabel{\@arabic\c@enumiv}}%
           {\ifthenelse{\boolean{@preprint}}{\normalsize}{\small}%
           \settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth%
            \advance\leftmargin\labelsep
            \@openbib@code%
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist
     }
\newenvironment{thereferences}[1]{%
    \section*{References}%
    \sel@V@e
    \list{\@biblabel{\@arabic\c@enumiv}}%
        {\ifthenelse{\boolean{@preprint}}{\normalsize}{\small}%
           \settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist
}

%%%%%%% Overriding headers and footers
\headheight = 14pt
\newcommand{\author@s}{%
    \ifthenelse{\equal{\theauthorsshort}{}}
        {\ifthenelse{\boolean{@leng}}
            {\sel@V@e\theauthoreng@other}
            {\let\thefootnote\relax\sel@V@r\theauthorrus}}
        {\ifthenelse{\boolean{@leng}}{\sel@V@e}{\sel@V@r}
            \theauthorsshort}
}
\newcommand{\titles@s}{%
    \ifthenelse{\boolean{@leng}}
        {\ifthenelse{\equal{\thetitleengshort}{}}
            {\sel@V@e\thetitleeng}
            {\sel@V@r\thetitleengshort}}
        {\sel@V@r\thetitleshort}
}
\ifthenelse{\boolean{@preprint}}{}{%
    \pagestyle{fancy}
    \lhead[\ifthenelse{\boolean{@merge}}{}{\thepage}]{}
    \chead[\small\author@s]{\small\titles@s}
    \rhead[]{\ifthenelse{\boolean{@merge}}{}{\thepage}}
    \cfoot[]{}
}

%%%%%%% Overriding sections
\renewcommand\section{\@startsection{section}{1}{0mm}%
                      {-2ex \@plus -.5ex \@minus -.2ex}%
                      {1ex \@plus.2ex \@minus -.2ex}%
                      {\@addtoreset{equation}{section}
                      \normalfont\normalsize\bfseries\raggedright\centering}%
}
\renewcommand\subsection{\@startsection{subsection}{2}{0mm}%
                      {-2ex\@plus -.5ex \@minus -.2ex}%
                      {1ex \@plus .2ex \@minus -.2ex}%
                      {\normalfont\normalsize\slshape\raggedright\centering}%
}
\renewcommand{\@seccntformat}[1]{%
    \csname the#1\endcsname.\@enspace%
}
\renewcommand\thesubsection{%
    \thesection.\arabic{subsection}\hskip 0.0em%
}
\renewcommand\thesubsubsection{%
    \thesubsection.\arabic{subsubsection}\hskip -0.0em%
}
\long\def\theequation{%
    \ifnum\c@section>\z@\thesection.\fi\@arabic\c@equation
}
    
%%%%%%% Overriding lists

\newcommand{\mbullet}{\raise.07em\hbox{\scalebox{.7}{$\bullet$}}}

\def\@listI{\leftmargin\leftmargini%
    \topsep\z@ \parsep\z@ \itemsep.3ex
}
\def\@listii{\leftmargin\leftmarginii%
    \labelwidth\leftmarginii\advance\labelwidth-\labelsep
    \topsep\z@ \parsep\z@ \itemsep\z@
}
\def\itemize{\ifnum\@itemdepth>\@ne \@toodeep \else \advance\@itemdepth\@ne
    \vskip .1ex plus 0.3ex minus 0.2ex\leftmarginii 10\p@
    \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
%    \list{\csname\@itemitem\endcsname}%
    \list{\mbullet}%
    {\def\makelabel##1{\hss\llap{##1}}}\fi
}
\def\enumerate{\ifnum\@enumdepth>\@ne \@toodeep \else
    \advance\@enumdepth\@ne
    \settowidth\leftmargini {\indent 9)\enskip}
    \leftmarginii 27\p@
    \edef\@enumctr{enum\romannumeral\the\@enumdepth}\list
    {\csname label\@enumctr\endcsname}{\usecounter
        {\@enumctr}\def\makelabel##1{\hss\llap{##1}}}\fi
}
\def\labelitemi{\textbullet}
\def\labelitemii{--}
\def\labelenumi{\theenumi)}
\def\labelenumii{\theenumii)}
\def\theenumi{\arabic{enumi}}
\def\theenumii{\alph{enumii}}
    
%%%%%%% Environments for theorems, lemmas, proofs, notes, etc.
\newenvironment{prop}[2][s]{%
    \vskip1mm 
    \ifthenelse{\equal{#1}{s}}
        {{\bf\@enspace#2.}}
        {{\bf\@enspace#2 #1.}}}
        {\par\vskip1mm}
\renewenvironment{proof}[1][s]{%
    \vskip1mm
    \ifthenelse{\equal{#1}{s}}
        {{\it%
        \ifthenelse{\boolean{@leng}}
        	{\s@V@proofeng}{\s@V@proofrus}.\@enspace}}
        {{\it#1.\@enspace}}}
        {\small$\square$\normalsize\par\vskip1mm}

%%%%%%% Definitions of new and override some standard commands
\newcommand\const{{\mathrm{const}}}
\renewcommand\Re{\mathop{\mathrm{Re}}\nolimits}
\renewcommand\Im{\mathop{\mathrm{Im}}\nolimits}
\newcommand\ci{\mathop{\textrm{ci}}\nolimits}
\newcommand\si{\mathop{\textrm{si}}\nolimits}
\newcommand\grad{\mathop{\mathrm{grad}}\nolimits}
\newcommand\rot{\mathop{\mathrm{rot}}\nolimits}
\newcommand\graddiv{\mathop{\mathrm{graddiv}}\nolimits}
\renewcommand\div{\mathop{\mathrm{div}}\nolimits}
\newcommand\sign{\mathop{\mathrm{sign}}\nolimits}
\newcommand\ReGoth{%
    \ensuremath{\text{\usefont{OMS}{cmr}{m}{n}\symbol{"3C}}}}
\newcommand\ImGoth{%
    \ensuremath{\text{\usefont{OMS}{cmr}{m}{n}\symbol{"3D}}}}
\ifx\No\undefined\newcommand\No{\textnumero}
    \else\renewcommand\No{\textnumero}\fi
	
\ExplSyntaxOn
\@ifpackageloaded{bm}{}{%
	\NewDocumentCommand\bm{m}{\ifmmode\pluton_bm:n{#1}\else\textbf{#1}\fi}
	\cs_new_protected:Npn \pluton_bm:n #1{%
		\tl_map_inline:nn{#1}{%
		\pluton_bm_inner:n{##1}}}
	\cs_new_protected:Npn \pluton_bm_inner:n #1{%
		\tl_if_in:VnTF \g_pluton_latin_tl{#1}{%
			\textbf{#1}}{%
		\tl_if_in:VnTF \g_pluton_greek_tl{#1}{%
		\boldsymbol{#1}}{#1}}}
	\tl_new:N \g_pluton_latin_tl
	\tl_new:N \g_pluton_greek_tl
	\tl_gset:Nn \g_pluton_latin_tl{
		ABCDEFGHIJKLMNOPQRSTUVWXYZ
		abcdefghijklmnopqrstuvwxyz}
	\tl_gset:Nn \g_pluton_greek_tl{%
		\alpha\beta\gamma\Gamma\delta\Delta\epsilon\varepsilon\zeta\eta
		\theta\vartheta\Theta\iota\kappa\varkappa\lambda\Lambda\mu\nu\xi
		\Xi\pi\Pi\rho\varrho\sigma\Sigma\tau\upsilon\Upsilon\phi\varphi\Phi
		\chi\psi\omega\Omega}
}
\ExplSyntaxOff

\let\vector\vec
\renewcommand\vec[1]{\mathbf{#1}}
\newcommand*{\dm}[1]{#1\nobreak\discretionary{}
    {\hbox{$\mathsurround=0pt #1$}}{}}
\renewcommand{\d}%
   {\@ifnextchar^{\DIfF}{\DIfF^{}}}
\def\DIfF^#1{%
   \mathop{\mathrm{\mathstrut d}}%
      \nolimits^{#1}\gobblespace
}
\def\gobblespace{%
   \futurelet\diffarg\opspace}
\def\opspace{%
   \let\DiffSpace\!%
   \ifx\diffarg(%
      \let\DiffSpace\relax
   \else
      \ifx\diffarg\[%
         \let\DiffSpace\relax
      \else
         \ifx\diffarg\{%
            \let\DiffSpace\relax
         \fi\fi\fi\DiffSpace}
  
%%%%%%% Required settings for tables
\ifthenelse{\boolean{@preprint}}
    {\setlength{\extrarowheight}{-2pt}}
    {\setlength{\extrarowheight}{1pt}}
\newcolumntype{Y}{>{%
	\ifthenelse{\boolean{@preprint}}{\small}{\footnotesize}%
	\centering\arraybackslash}X}
\newcolumntype{C}{>{%
	\ifthenelse{\boolean{@preprint}}{\small}{\footnotesize}%
	\arraybackslash}c}
\newcolumntype{L}{>{%
	\ifthenelse{\boolean{@preprint}}{\small}{\footnotesize}%
	\arraybackslash}l}
\newcolumntype{R}{>{%
	\ifthenelse{\boolean{@preprint}}{\small}{\footnotesize}%
	\arraybackslash}r}
\newcolumntype{P}{>{%
	\ifthenelse{\boolean{@preprint}}{\small}{\footnotesize}%
	\centering\arraybackslash}p}
\newcolumntype{Q}{>{%
	\ifthenelse{\boolean{@preprint}}{\small}{\footnotesize}%
	\raggedright\arraybackslash}p}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\makeatother
\endinput